/***********************************************************************

	File:	bsd.h
	Rev:	a-1
	Date:	10/04/98

	Copyright (c) 1998, 1999, by David M. Warme

************************************************************************

	Declarations for the rectilinear Bottleneck Steiner Distance
	implementation.

************************************************************************

	Modification Log:

	a-1:	10/04/98	warme
		: Created.

************************************************************************/

#ifndef	BSD_H
#define	BSD_H

#include "steiner.h"


/*
 * A structure for representing an MST in adjacency list format.
 */

struct mstadj {
	int16u		edge;		/* Edge number */
	int16u		pnum;		/* Index of other vertex */
};


/*
 * A structure to encapsulate all the data we store for rapidly
 * computing the BSD of two terminals.
 */

struct bsd {
	int			method;	/* Implementation method to use */

	/* Stuff common to all implementations. */
	int			n;		/* Number of terminals */
	struct edge *		mst_edges;	/* List of MST edges */
	struct mstadj **	adj_list;	/* Adjacency list */
	bool *			mark;		/* Marks terminals visited */

	/* Stuff for the Lower Triangular matrix of edge #'s implementation. */
	int16u *	ematrix;	/* The full matrix */

	/* Stuff for the row-cache implementation. */
};


extern dist_t		bsd (struct bsd *, int, int);
extern struct bsd *	compute_bsd (int, struct edge *, int);
extern void		shutdown_bsd (struct bsd *);

#endif
